#include <algorithm>
#include <iostream>
#include <numeric>
#include <queue>
#include <vector>

using namespace std;

constexpr int S  = 400;
constexpr int SS = S * 2;
int LLINF        = 1e9;
using ll         = long long;

struct Edge {
	int v;
	ll weight;
}; // input edges
struct PQ {
	ll d;
	int v;
}; // distance and target
bool operator>(const PQ& l, const PQ& r) {
	return l.d > r.d;
}
vector<ll> dijkstra(vector<vector<Edge>>& edges, int s) {
	vector<ll> dist(edges.size(), LLINF);
	priority_queue<PQ, vector<PQ>, greater<PQ>> pq;
	dist[s] = 0;
	pq.push({0, s});
	while(!pq.empty()) {
		auto d = pq.top().d;
		auto u = pq.top().v;
		pq.pop();
		if(d == dist[u])
			for(auto& e : edges[u])
				if(dist[e.v] > d + e.weight) pq.push({dist[e.v] = d + e.weight, e.v});
	}
	return dist;
}

int main() {
	std::ios_base::sync_with_stdio(false);
	cin.tie(nullptr);
	int n, s;
	cin >> n >> s;

	vector<vector<Edge>> g(2 * s);

	// left: 0..s
	// right: s..2s
	vector<pair<int, int>> ps(n);
	for(auto& p : ps) {
		cin >> p.first >> p.second;
		--p.first;
		--p.second;
		p.second += s;
		g[p.first].push_back(Edge{p.second, 1});
		g[p.second].push_back(Edge{p.first, 1});
	}

	vector<vector<long long>> dists(2 * s);
	for(int i = 0; i < 2 * s; ++i) {
		dists[i] = dijkstra(g, i);
	}

	int q;
	cin >> q;
	for(int i = 0; i < q; ++i) {
		int x, y;
		cin >> x >> y;
		--x, --y;
		long long d = LLINF;
		d           = min(d, dists[ps[x].first][ps[y].first]);
		d           = min(d, dists[ps[x].first][ps[y].second]);
		d           = min(d, dists[ps[x].second][ps[y].first]);
		d           = min(d, dists[ps[x].second][ps[y].second]);
		cout << (d == LLINF ? -1 : d + 1) << endl;
	}
}
